# -*- coding: utf-8 -*-
"""
Pull opendc solution images to the Docker repository cache.

usage:
  opendc [--debug] pull [<solution>] [--help | -h]

options:
  <solution>    is a specific solution images to pull.
  -h, --help    show this help.
  --debug       show debug output.

example:
  opendc pull
  opendc pull dbs1_distributed_block_storage
"""

import logging
import os
from docopt import docopt
from opendc.utility import call_ansible

logger = logging.getLogger(__name__)


class PullCmd(object):
  """Pull opendc solution images to the Docker repository cache."""

  tag = None

  def parse(self, argv):
    args = docopt(__doc__, argv=argv)
    logger.debug("opendc pull - args:\n{}".format(args))
    self.tag = args['<solution>']

  def run(self):
    if self.tag is not None:
      self.tag = [self.tag]

    call_ansible(os.path.realpath(os.path.join(os.path.curdir, 'playbooks/pull.yaml')), 
                 tag = self.tag )



# -*- coding: utf-8 -*-
"""
Deploy opendc solutions to the k8s cluster.

usage:
  opendc [--debug] sol [<solution>] [--help | -h]

options:
  <solution>    is a specific solution to deploy.
  -h, --help    show this help.
  --debug       show debug output.

example:
  opendc sol
  opendc sol cs1_cluster_services
"""

import logging
import os
from docopt import docopt
from opendc.utility import call_ansible

logger = logging.getLogger(__name__)


class SolCmd(object):
  """Deploy opendc solutions to the k8s cluster."""

  def parse(self, argv):
    args = docopt(__doc__, argv=argv)
    logger.debug("opendc sol - args:\n{}".format(args))
    self.tag = args['<solution>']

  def run(self):
    if self.tag is not None:
      self.tag = [self.tag]

    call_ansible(os.path.realpath(os.path.join(os.path.curdir, 'playbooks/sol.yaml')), 
                 tag = self.tag )



# -*- coding: utf-8 -*-
"""
Create provider specific files from templates.

usage:
  opendc [--debug] template [--help | -h]

options:
  -h, --help    show this help.
  --debug       show debug output.

example:
  opendc template
"""

import logging
from docopt import docopt
from opendc.provider import get_provider

logger = logging.getLogger(__name__)


class TemplateCmd(object):
  """Create provider specific files from templates."""

  def parse(self, argv):
    args = docopt(__doc__, argv=argv)
    logger.debug("opendc template - args:\n{}".format(args))

  def run(self):
    provider = get_provider()
    provider.create_files()
